Payu
====

.. image:: https://github.com/payu-org/payu/actions/workflows/CI.yml/badge.svg
    :target: https://github.com/payu-org/payu/actions/workflows/CI.yml
.. image:: https://github.com/payu-org/payu/actions/workflows/CD.yml/badge.svg
    :target: https://github.com/payu-org/payu/actions/workflows/CD.yml
.. image:: https://coveralls.io/repos/github/payu-org/payu/badge.svg?branch=master&killcache=1
    :target: https://coveralls.io/github/payu-org/payu?branch=master
.. image:: https://readthedocs.org/projects/docs/badge/?version=latest
    :target: https://payu.readthedocs.io/en/latest/

Payu is a climate model workflow management tool for supercomputing
environments.

Payu is currently only configured for use on computing clusters maintained by
NCI (National Computational Infrastructure) in Australia.

See the documentation_ for more details.

.. _documentation: http://payu.readthedocs.org/en/latest/
